Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Instance ¶
type Instance struct {
// contains filtered or unexported fields
}
Instance is a compiled wazero instance.
func (*Instance) Run ¶
func (w *Instance) Run(ctx context.Context, stdin io.Reader, stdout, stderr io.Writer, fsMap map[string]fs.FS, args ...string) error
Run runs the wasm module with the context, arguments, and optional stdin, stdout, stderr, and filesystem map. Supply a context with a timeout or other cancellation mechanism to control execution time. Returns an error if instantiation fails.
Click to show internal directories.
Click to hide internal directories.